Index

A C D E F G H I L M N O P R S T 
All Classes and Interfaces|All Packages

A

addDefaultRequestInterceptorCustomizer() - Method in class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignAutoConfiguration
Creates a FeignBuilderCustomizer that adds the NoOpRequestInterceptor as a default request interceptor to every Feign client builder.
addRequestInterceptor(RequestInterceptor) - Method in class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
Adds a RequestInterceptor to this composite.
apply(RequestTemplate) - Method in class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
Applies all registered RequestInterceptor instances to the given RequestTemplate in order.
apply(RequestTemplate) - Method in class io.microsphere.spring.cloud.openfeign.components.NoOpRequestInterceptor
Applies this interceptor to the given RequestTemplate.
AutoRefreshCapability - Class in io.microsphere.spring.cloud.openfeign.autorefresh
 
AutoRefreshCapability(FeignClientProperties, NamedContextFactory<FeignClientSpecification>, FeignComponentRegistry) - Constructor for class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Constructs an AutoRefreshCapability with the required dependencies.

C

clone() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedRetryer
Returns a clone of the delegate Retryer.
componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedContract
Returns the configured Contract class from FeignClientProperties.FeignClientConfiguration, falling back to Contract if not configured.
componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedDecoder
Returns the configured Decoder class from FeignClientProperties.FeignClientConfiguration, falling back to Decoder if not configured.
componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedEncoder
Returns the configured Encoder class from FeignClientProperties.FeignClientConfiguration, falling back to Encoder if not configured.
componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedErrorDecoder
Returns the configured ErrorDecoder class from FeignClientProperties.FeignClientConfiguration, falling back to ErrorDecoder.Default if not configured.
componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Returns the Feign component type class used to resolve the delegate implementation.
componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedQueryMapEncoder
Returns the configured QueryMapEncoder class from FeignClientProperties.FeignClientConfiguration, falling back to PageableSpringQueryMapEncoder if not configured.
componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedRetryer
Returns the configured Retryer class from FeignClientProperties.FeignClientConfiguration, falling back to Retryer if not configured.
CompositedRequestInterceptor - Class in io.microsphere.spring.cloud.openfeign.components
 
CompositedRequestInterceptor(String, BeanFactory) - Constructor for class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
Constructs a CompositedRequestInterceptor for the specified Feign client context.
contextId() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Returns the Feign client context ID associated with this decorated component.
continueOrPropagate(RetryableException) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedRetryer
Continues or propagates the retry by delegating to the underlying Retryer.

D

decode(Response, Type) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedDecoder
Decodes a Feign Response into an object of the given type by delegating to the underlying Decoder.
decode(String, Response) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedErrorDecoder
Decodes an error response by delegating to the underlying ErrorDecoder.
DecoratedContract - Class in io.microsphere.spring.cloud.openfeign.components
 
DecoratedContract(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, Contract) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedContract
Constructs a DecoratedContract wrapping the given Contract delegate.
DecoratedDecoder - Class in io.microsphere.spring.cloud.openfeign.components
 
DecoratedDecoder(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, Decoder) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedDecoder
Constructs a DecoratedDecoder wrapping the given Decoder delegate.
DecoratedEncoder - Class in io.microsphere.spring.cloud.openfeign.components
 
DecoratedEncoder(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, Encoder) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedEncoder
Constructs a DecoratedEncoder wrapping the given Encoder delegate.
DecoratedErrorDecoder - Class in io.microsphere.spring.cloud.openfeign.components
 
DecoratedErrorDecoder(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, ErrorDecoder) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedErrorDecoder
Constructs a DecoratedErrorDecoder wrapping the given ErrorDecoder delegate.
DecoratedFeignComponent<T> - Class in io.microsphere.spring.cloud.openfeign.components
 
DecoratedFeignComponent(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, T) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Constructs a DecoratedFeignComponent wrapping the given delegate.
DecoratedQueryMapEncoder - Class in io.microsphere.spring.cloud.openfeign.components
 
DecoratedQueryMapEncoder(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, QueryMapEncoder) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedQueryMapEncoder
Constructs a DecoratedQueryMapEncoder wrapping the given QueryMapEncoder delegate.
DecoratedRetryer - Class in io.microsphere.spring.cloud.openfeign.components
 
DecoratedRetryer(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, Retryer) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedRetryer
Constructs a DecoratedRetryer wrapping the given Retryer delegate.
delegate - Variable in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
 
delegate() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Returns the current delegate instance, lazily loading it from the context factory if it was previously cleared by a DecoratedFeignComponent.refresh() call.

E

EnableFeignAutoRefresh - Annotation Interface in io.microsphere.spring.cloud.openfeign.autorefresh
Enable Feign Auto Refresh
EnableFeignAutoRefresh.Marker - Class in io.microsphere.spring.cloud.openfeign.autorefresh
 
encode(Object) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedQueryMapEncoder
Encodes the given object into a query parameter map by delegating to the underlying QueryMapEncoder.
encode(Object, Type, RequestTemplate) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedEncoder
Encodes the given object into the RequestTemplate by delegating to the underlying Encoder.
enrich(Decoder) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Enriches the given Decoder by wrapping it in a DecoratedDecoder that supports auto-refresh on configuration changes.
enrich(Encoder) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Enriches the given Encoder by wrapping it in a DecoratedEncoder that supports auto-refresh on configuration changes.
enrich(ErrorDecoder) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Enriches the given ErrorDecoder by wrapping it in a DecoratedErrorDecoder that supports auto-refresh on configuration changes.
enrich(Contract) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Enriches the given Contract by wrapping it in a DecoratedContract that supports auto-refresh on configuration changes.
enrich(QueryMapEncoder) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Enriches the given QueryMapEncoder by wrapping it in a DecoratedQueryMapEncoder that supports auto-refresh on configuration changes.
enrich(RequestInterceptor) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Enriches the given RequestInterceptor by registering it in the FeignComponentRegistry as part of a CompositedRequestInterceptor.
enrich(Retryer) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Enriches the given Retryer by wrapping it in a DecoratedRetryer that supports auto-refresh on configuration changes.
equals(Object) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent

F

FeignAutoConfiguration - Class in io.microsphere.spring.cloud.openfeign.autoconfigure
The Auto-Configuration class for Spring Cloud OpenFeign
FeignAutoConfiguration() - Constructor for class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignAutoConfiguration
 
FeignClientAutoRefreshAutoConfiguration - Class in io.microsphere.spring.cloud.openfeign.autoconfigure
The Auto-Configuration class for EnableFeignAutoRefresh
FeignClientAutoRefreshAutoConfiguration() - Constructor for class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignClientAutoRefreshAutoConfiguration
 
FeignClientConfigurationChangedListener - Class in io.microsphere.spring.cloud.openfeign.autorefresh
 
FeignClientConfigurationChangedListener(FeignComponentRegistry) - Constructor for class io.microsphere.spring.cloud.openfeign.autorefresh.FeignClientConfigurationChangedListener
Constructs a listener that refreshes Feign components when the environment changes.
feignClientRegistry(FeignClientProperties, BeanFactory) - Method in class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignClientAutoRefreshAutoConfiguration
Creates the FeignComponentRegistry bean that tracks decorated Feign components and supports auto-refresh when configuration properties change.
FeignComponentRegistry - Class in io.microsphere.spring.cloud.openfeign.autorefresh
Feign Component Registry
FeignComponentRegistry(String, BeanFactory) - Constructor for class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
Constructs a FeignComponentRegistry with the given default client name and BeanFactory.

G

get(Function<FeignClientProperties.FeignClientConfiguration, T>) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Retrieves a value from the FeignClientProperties.FeignClientConfiguration using the provided function, checking the default configuration first and then the current context configuration.
getComponentClass(String) - Static method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
Returns the Feign component class corresponding to the given configuration key.
getCurrentConfiguration() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Returns the FeignClientProperties.FeignClientConfiguration for the current Feign client context ID.
getDefaultConfiguration() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Returns the default FeignClientProperties.FeignClientConfiguration as defined by the FeignClientProperties.getDefaultConfig() key.
getRequestInterceptors() - Method in class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
Returns an unmodifiable view of the registered RequestInterceptor instances.

H

hashCode() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent

I

INSTANCE - Static variable in class io.microsphere.spring.cloud.openfeign.components.NoOpRequestInterceptor
A no-operation RequestInterceptor that does nothing when applied.
instantiate(Class<W>, Class<? extends T>, String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, T) - Static method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Factory method to instantiate a DecoratedFeignComponent subclass by locating the appropriate constructor via reflection.
io.microsphere.spring.cloud.openfeign.autoconfigure - package io.microsphere.spring.cloud.openfeign.autoconfigure
 
io.microsphere.spring.cloud.openfeign.autorefresh - package io.microsphere.spring.cloud.openfeign.autorefresh
 
io.microsphere.spring.cloud.openfeign.components - package io.microsphere.spring.cloud.openfeign.components
 

L

loadInstance() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Loads the delegate instance from the NamedContextFactory using the component type returned by DecoratedFeignComponent.componentType().
loadInstanceFromContextFactory(String, Class<T>) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Loads a component instance of the given type from the NamedContextFactory, falling back to direct instantiation if the bean is not available.
logger - Variable in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
 

M

Marker() - Constructor for class io.microsphere.spring.cloud.openfeign.autorefresh.EnableFeignAutoRefresh.Marker
 

N

NoOpRequestInterceptor - Class in io.microsphere.spring.cloud.openfeign.components
 
NoOpRequestInterceptor() - Constructor for class io.microsphere.spring.cloud.openfeign.components.NoOpRequestInterceptor
 

O

onApplicationEvent(EnvironmentChangeEvent) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignClientConfigurationChangedListener
Handles an EnvironmentChangeEvent by resolving which Feign clients are affected and triggering a refresh on the corresponding components in the registry.
onApplicationReadyEvent(ApplicationReadyEvent) - Method in class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignClientAutoRefreshAutoConfiguration
Handles the ApplicationReadyEvent to register the FeignClientConfigurationChangedListener after the application is fully initialized.

P

parseAndValidateMetadata(Class<?>) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedContract
Parses and validates metadata for the given target type by delegating to the underlying Contract.

R

refresh() - Method in class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
Refreshes the set of RequestInterceptor instances by re-reading the FeignClientProperties configuration for request interceptors, default headers, and default query parameters.
refresh() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
Refreshes this component by clearing the delegate, causing the next call to DecoratedFeignComponent.delegate() to reload the instance from the context factory.
refresh() - Method in interface io.microsphere.spring.cloud.openfeign.components.Refreshable
Refresh
refresh(String, String...) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
Refreshes the Feign components for the specified client whose configurations have changed.
refresh(String, Set<String>) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
Refreshes the Feign components for the specified client based on a set of changed configuration keys.
Refreshable - Interface in io.microsphere.spring.cloud.openfeign.components
 
register(String, Refreshable) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
Registers a single Refreshable component for the specified Feign client.
register(String, List<Refreshable>) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
Registers a list of Refreshable components for the specified Feign client.
registerRequestInterceptor(String, RequestInterceptor) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
Registers a RequestInterceptor for the specified Feign client.
resolveChangedClient(EnvironmentChangeEvent) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignClientConfigurationChangedListener
Resolves which Feign client names and their changed configuration keys are affected by the given EnvironmentChangeEvent.

S

setApplicationContext(ApplicationContext) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
Sets the ApplicationContext and extracts the Feign client context ID from the spring.cloud.openfeign.client.name property.

T

toString() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
A C D E F G H I L M N O P R S T 
All Classes and Interfaces|All Packages