Index
All Classes and Interfaces|All Packages
A
- addDefaultRequestInterceptorCustomizer() - Method in class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignAutoConfiguration
-
Creates a
FeignBuilderCustomizerthat adds theNoOpRequestInterceptoras a default request interceptor to every Feign client builder. - addRequestInterceptor(RequestInterceptor) - Method in class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
-
Adds a
RequestInterceptorto this composite. - apply(RequestTemplate) - Method in class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
-
Applies all registered
RequestInterceptorinstances to the givenRequestTemplatein order. - apply(RequestTemplate) - Method in class io.microsphere.spring.cloud.openfeign.components.NoOpRequestInterceptor
-
Applies this interceptor to the given
RequestTemplate. - AutoRefreshCapability - Class in io.microsphere.spring.cloud.openfeign.autorefresh
- AutoRefreshCapability(FeignClientProperties, NamedContextFactory<FeignClientSpecification>, FeignComponentRegistry) - Constructor for class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Constructs an
AutoRefreshCapabilitywith the required dependencies.
C
- clone() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedRetryer
-
Returns a clone of the delegate
Retryer. - componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedContract
-
Returns the configured
Contractclass fromFeignClientProperties.FeignClientConfiguration, falling back toContractif not configured. - componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedDecoder
-
Returns the configured
Decoderclass fromFeignClientProperties.FeignClientConfiguration, falling back toDecoderif not configured. - componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedEncoder
-
Returns the configured
Encoderclass fromFeignClientProperties.FeignClientConfiguration, falling back toEncoderif not configured. - componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedErrorDecoder
-
Returns the configured
ErrorDecoderclass fromFeignClientProperties.FeignClientConfiguration, falling back toErrorDecoder.Defaultif not configured. - componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Returns the Feign component type class used to resolve the delegate implementation.
- componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedQueryMapEncoder
-
Returns the configured
QueryMapEncoderclass fromFeignClientProperties.FeignClientConfiguration, falling back toPageableSpringQueryMapEncoderif not configured. - componentType() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedRetryer
-
Returns the configured
Retryerclass fromFeignClientProperties.FeignClientConfiguration, falling back toRetryerif not configured. - CompositedRequestInterceptor - Class in io.microsphere.spring.cloud.openfeign.components
- CompositedRequestInterceptor(String, BeanFactory) - Constructor for class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
-
Constructs a
CompositedRequestInterceptorfor the specified Feign client context. - contextId() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Returns the Feign client context ID associated with this decorated component.
- continueOrPropagate(RetryableException) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedRetryer
-
Continues or propagates the retry by delegating to the underlying
Retryer.
D
- decode(Response, Type) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedDecoder
-
Decodes a Feign
Responseinto an object of the given type by delegating to the underlyingDecoder. - decode(String, Response) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedErrorDecoder
-
Decodes an error response by delegating to the underlying
ErrorDecoder. - DecoratedContract - Class in io.microsphere.spring.cloud.openfeign.components
- DecoratedContract(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, Contract) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedContract
-
Constructs a
DecoratedContractwrapping the givenContractdelegate. - DecoratedDecoder - Class in io.microsphere.spring.cloud.openfeign.components
- DecoratedDecoder(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, Decoder) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedDecoder
-
Constructs a
DecoratedDecoderwrapping the givenDecoderdelegate. - DecoratedEncoder - Class in io.microsphere.spring.cloud.openfeign.components
- DecoratedEncoder(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, Encoder) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedEncoder
-
Constructs a
DecoratedEncoderwrapping the givenEncoderdelegate. - DecoratedErrorDecoder - Class in io.microsphere.spring.cloud.openfeign.components
- DecoratedErrorDecoder(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, ErrorDecoder) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedErrorDecoder
-
Constructs a
DecoratedErrorDecoderwrapping the givenErrorDecoderdelegate. - DecoratedFeignComponent<T> - Class in io.microsphere.spring.cloud.openfeign.components
- DecoratedFeignComponent(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, T) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Constructs a
DecoratedFeignComponentwrapping the given delegate. - DecoratedQueryMapEncoder - Class in io.microsphere.spring.cloud.openfeign.components
- DecoratedQueryMapEncoder(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, QueryMapEncoder) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedQueryMapEncoder
-
Constructs a
DecoratedQueryMapEncoderwrapping the givenQueryMapEncoderdelegate. - DecoratedRetryer - Class in io.microsphere.spring.cloud.openfeign.components
- DecoratedRetryer(String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, Retryer) - Constructor for class io.microsphere.spring.cloud.openfeign.components.DecoratedRetryer
-
Constructs a
DecoratedRetryerwrapping the givenRetryerdelegate. - delegate - Variable in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
- delegate() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Returns the current delegate instance, lazily loading it from the context factory if it was previously cleared by a
DecoratedFeignComponent.refresh()call.
E
- EnableFeignAutoRefresh - Annotation Interface in io.microsphere.spring.cloud.openfeign.autorefresh
-
Enable Feign Auto Refresh
- EnableFeignAutoRefresh.Marker - Class in io.microsphere.spring.cloud.openfeign.autorefresh
- encode(Object) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedQueryMapEncoder
-
Encodes the given object into a query parameter map by delegating to the underlying
QueryMapEncoder. - encode(Object, Type, RequestTemplate) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedEncoder
-
Encodes the given object into the
RequestTemplateby delegating to the underlyingEncoder. - enrich(Decoder) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Enriches the given
Decoderby wrapping it in aDecoratedDecoderthat supports auto-refresh on configuration changes. - enrich(Encoder) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Enriches the given
Encoderby wrapping it in aDecoratedEncoderthat supports auto-refresh on configuration changes. - enrich(ErrorDecoder) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Enriches the given
ErrorDecoderby wrapping it in aDecoratedErrorDecoderthat supports auto-refresh on configuration changes. - enrich(Contract) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Enriches the given
Contractby wrapping it in aDecoratedContractthat supports auto-refresh on configuration changes. - enrich(QueryMapEncoder) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Enriches the given
QueryMapEncoderby wrapping it in aDecoratedQueryMapEncoderthat supports auto-refresh on configuration changes. - enrich(RequestInterceptor) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Enriches the given
RequestInterceptorby registering it in theFeignComponentRegistryas part of aCompositedRequestInterceptor. - enrich(Retryer) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Enriches the given
Retryerby wrapping it in aDecoratedRetryerthat supports auto-refresh on configuration changes. - equals(Object) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
F
- FeignAutoConfiguration - Class in io.microsphere.spring.cloud.openfeign.autoconfigure
-
The Auto-Configuration class for Spring Cloud OpenFeign
- FeignAutoConfiguration() - Constructor for class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignAutoConfiguration
- FeignClientAutoRefreshAutoConfiguration - Class in io.microsphere.spring.cloud.openfeign.autoconfigure
-
The Auto-Configuration class for
EnableFeignAutoRefresh - FeignClientAutoRefreshAutoConfiguration() - Constructor for class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignClientAutoRefreshAutoConfiguration
- FeignClientConfigurationChangedListener - Class in io.microsphere.spring.cloud.openfeign.autorefresh
- FeignClientConfigurationChangedListener(FeignComponentRegistry) - Constructor for class io.microsphere.spring.cloud.openfeign.autorefresh.FeignClientConfigurationChangedListener
-
Constructs a listener that refreshes Feign components when the environment changes.
- feignClientRegistry(FeignClientProperties, BeanFactory) - Method in class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignClientAutoRefreshAutoConfiguration
-
Creates the
FeignComponentRegistrybean that tracks decorated Feign components and supports auto-refresh when configuration properties change. - FeignComponentRegistry - Class in io.microsphere.spring.cloud.openfeign.autorefresh
-
Feign Component Registry
- FeignComponentRegistry(String, BeanFactory) - Constructor for class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
-
Constructs a
FeignComponentRegistrywith the given default client name andBeanFactory.
G
- get(Function<FeignClientProperties.FeignClientConfiguration, T>) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Retrieves a value from the
FeignClientProperties.FeignClientConfigurationusing the provided function, checking the default configuration first and then the current context configuration. - getComponentClass(String) - Static method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
-
Returns the Feign component class corresponding to the given configuration key.
- getCurrentConfiguration() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Returns the
FeignClientProperties.FeignClientConfigurationfor the current Feign client context ID. - getDefaultConfiguration() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Returns the default
FeignClientProperties.FeignClientConfigurationas defined by theFeignClientProperties.getDefaultConfig()key. - getRequestInterceptors() - Method in class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
-
Returns an unmodifiable view of the registered
RequestInterceptorinstances.
H
- hashCode() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
I
- INSTANCE - Static variable in class io.microsphere.spring.cloud.openfeign.components.NoOpRequestInterceptor
-
A no-operation
RequestInterceptorthat does nothing when applied. - instantiate(Class<W>, Class<? extends T>, String, NamedContextFactory<FeignClientSpecification>, FeignClientProperties, T) - Static method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Factory method to instantiate a
DecoratedFeignComponentsubclass by locating the appropriate constructor via reflection. - io.microsphere.spring.cloud.openfeign.autoconfigure - package io.microsphere.spring.cloud.openfeign.autoconfigure
- io.microsphere.spring.cloud.openfeign.autorefresh - package io.microsphere.spring.cloud.openfeign.autorefresh
- io.microsphere.spring.cloud.openfeign.components - package io.microsphere.spring.cloud.openfeign.components
L
- loadInstance() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Loads the delegate instance from the
NamedContextFactoryusing the component type returned byDecoratedFeignComponent.componentType(). - loadInstanceFromContextFactory(String, Class<T>) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Loads a component instance of the given type from the
NamedContextFactory, falling back to direct instantiation if the bean is not available. - logger - Variable in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
M
- Marker() - Constructor for class io.microsphere.spring.cloud.openfeign.autorefresh.EnableFeignAutoRefresh.Marker
N
- NoOpRequestInterceptor - Class in io.microsphere.spring.cloud.openfeign.components
- NoOpRequestInterceptor() - Constructor for class io.microsphere.spring.cloud.openfeign.components.NoOpRequestInterceptor
O
- onApplicationEvent(EnvironmentChangeEvent) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignClientConfigurationChangedListener
-
Handles an
EnvironmentChangeEventby resolving which Feign clients are affected and triggering a refresh on the corresponding components in the registry. - onApplicationReadyEvent(ApplicationReadyEvent) - Method in class io.microsphere.spring.cloud.openfeign.autoconfigure.FeignClientAutoRefreshAutoConfiguration
-
Handles the
ApplicationReadyEventto register theFeignClientConfigurationChangedListenerafter the application is fully initialized.
P
- parseAndValidateMetadata(Class<?>) - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedContract
-
Parses and validates metadata for the given target type by delegating to the underlying
Contract.
R
- refresh() - Method in class io.microsphere.spring.cloud.openfeign.components.CompositedRequestInterceptor
-
Refreshes the set of
RequestInterceptorinstances by re-reading theFeignClientPropertiesconfiguration for request interceptors, default headers, and default query parameters. - refresh() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
-
Refreshes this component by clearing the delegate, causing the next call to
DecoratedFeignComponent.delegate()to reload the instance from the context factory. - refresh() - Method in interface io.microsphere.spring.cloud.openfeign.components.Refreshable
-
Refresh
- refresh(String, String...) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
-
Refreshes the Feign components for the specified client whose configurations have changed.
- refresh(String, Set<String>) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
-
Refreshes the Feign components for the specified client based on a set of changed configuration keys.
- Refreshable - Interface in io.microsphere.spring.cloud.openfeign.components
- register(String, Refreshable) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
-
Registers a single
Refreshablecomponent for the specified Feign client. - register(String, List<Refreshable>) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
-
Registers a list of
Refreshablecomponents for the specified Feign client. - registerRequestInterceptor(String, RequestInterceptor) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignComponentRegistry
-
Registers a
RequestInterceptorfor the specified Feign client. - resolveChangedClient(EnvironmentChangeEvent) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.FeignClientConfigurationChangedListener
-
Resolves which Feign client names and their changed configuration keys are affected by the given
EnvironmentChangeEvent.
S
- setApplicationContext(ApplicationContext) - Method in class io.microsphere.spring.cloud.openfeign.autorefresh.AutoRefreshCapability
-
Sets the
ApplicationContextand extracts the Feign client context ID from thespring.cloud.openfeign.client.nameproperty.
T
- toString() - Method in class io.microsphere.spring.cloud.openfeign.components.DecoratedFeignComponent
All Classes and Interfaces|All Packages